@@ -54,8 +54,18 @@ class RegressionReport:
         >>> r2 = report["r2_score"]  # get specific metric
         -3.000
     """
-    def __init__(self, y_true, y_pred):
+    def __init__(self, y_true, y_pred, drop_zeros=False):
+        """
+
+        Args:
+            y_true: 1d np.array of actual y values example=np.array([1,2,3,4,5])
+            y_pred: 1d np.array of predicted y values example=np.array([1,2,3,4,5])
+            drop_zeros: If true drop any zeros in y_true and the corresponding value in y_pred for percentage based
+             metrics
+        """
         prefix = "metric_"  # all metric functions should have this prefix to be in the report
+        # some forecasting models drop zeros https://ideas.repec.org/a/for/ijafaa/y2006i4p32-35.html
+        self.drop_zeros = drop_zeros
         self._y_true, self._y_pred = self._check_arrays(y_true, y_pred)
         self._computed_metrics = {}
         for class_attribute in [x for x in dir(self) if prefix in x]:
@@ -128,7 +138,11 @@ class RegressionReport:
         return mse
 
     def metric_mean_squared_percentage_error(self):
-        mspe = np.mean(np.divide(np.square(self._y_true - self._y_pred), np.square(self._y_true)))
+        idx = np.s_[:]
+        if self.drop_zeros:
+            idx = self._y_true != 0
+        y, y_hat = self._y_true[idx], self._y_pred[idx]
+        mspe = np.mean(np.divide(np.square(y - y_hat), np.square(y)))
         return mspe
 
     def metric_root_mean_square_error(self):
@@ -136,7 +150,11 @@ class RegressionReport:
         return rmse
 
     def metric_root_mean_square_percentage_error(self):
-        rmspe = np.square(np.mean(np.divide(np.square(self._y_true - self._y_pred), np.square(self._y_true))))
+        idx = np.s_[:]
+        if self.drop_zeros:
+            idx = self._y_true != 0
+        y, y_hat = self._y_true[idx], self._y_pred[idx]
+        rmspe = np.square(np.mean(np.divide(np.square(y - y_hat), np.square(y))))
         return rmspe
 
     def metric_mean_absolute_error(self):
@@ -144,7 +162,11 @@ class RegressionReport:
         return mae
 
     def metric_mean_absolute_percentage_error(self):
-        mape = np.mean(np.abs(np.divide((self._y_true - self._y_pred), self._y_true)))
+        idx = np.s_[:]
+        if self.drop_zeros:
+            idx = self._y_true != 0
+        y, y_hat = self._y_true[idx], self._y_pred[idx]
+        mape = np.mean(np.abs(np.divide((y - y_hat), y)))
         return mape
 
     def metric_relative_squared_error(self):
